import csv
import requests
import xml.etree.ElementTree as ET
import os
import re

def download_xml_file(url, xml_file):
    response = requests.get(url, verify=False)
    with open(xml_file, 'wb') as file:
        file.write(response.content)

def clean_kod_producenta(kod_producenta):
    # Remove characters other than alphanumeric and "-"
    cleaned_kod_producenta = re.sub(r'[^a-zA-Z0-9-]', '', kod_producenta)
    return cleaned_kod_producenta

def load_prices_from_csv(csv_file):
    prices = {}
    with open(csv_file, 'r') as file:
        reader = csv.reader(file)
        next(reader)  # Skip the header row
        for row in reader:
            sku, price = row
            prices[sku] = price
    return prices

def extract_product_data(xml_file, csv_file):
    tree = ET.parse(xml_file)
    root = tree.getroot()

    prices = load_prices_from_csv(csv_file)

    with open('yope.csv', 'w', newline='') as file:
        writer = csv.writer(file)
        writer.writerow(['sku', 'price', 'qty'])

        for o in root.iter('o'):
            attrs = o.find('attrs')
            kod_producenta = attrs.find("./a[@name='Kod producenta']").text
            stock = o.get('stock')

            cleaned_kod_producenta = clean_kod_producenta(kod_producenta)
            
            if cleaned_kod_producenta in prices:
                price = prices[cleaned_kod_producenta]
            else:
                price = o.get('price')
            
            writer.writerow([cleaned_kod_producenta, price, stock])

    print(f"Data extracted and saved to '{csv_file}'.")

    # Delete the XML file
    os.remove(xml_file)

# Specify the URL to download the XML file and the desired paths for the XML and CSV files.
xml_url = 'https://api.yope.me/store-api/product-export/SWPET0FHS1DXMJZQAHZXBJN3MG/ceneo.xml'
xml_file_path = 'temporary_xml.xml'
csv_file_path = 'yope_files/prices.csv'

download_xml_file(xml_url, xml_file_path)
extract_product_data(xml_file_path, csv_file_path)
